@@ -602,15 +602,10 @@ class ImageResize(TypedDict):
     height: NotRequired[int]
 
 
-class ImageRotate(TypedDict):
-    angle: int
-
-
 class ImageOptions(TypedDict):
     format: NotRequired[ImageFormat]
     crop: NotRequired[ImageCrop]
     resize: NotRequired[ImageResize]
-    rotate: NotRequired[ImageRotate]
 
 
 class IceServer(TypedDict):
@@ -645,6 +640,8 @@ class FrameImage(TypedDict):
 
 
 class VideoFrame(Protocol):
+    image_buffer: bytes
+
     @property
     def metadata(self) -> FrameMetadata: ...
     @property
@@ -715,7 +712,8 @@ class CameraDevice(Protocol):
     async def disconnect(self) -> None: ...
     async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
-    async def generate_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
+    async def get_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
+    async def get_motion_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> list[IceServer]: ...
 
@@ -743,6 +741,7 @@ class CameraDevice(Protocol):
         self,
         state_name: Literal["motion"],
         event_data: MotionSetEvent,
+        frame: Optional[bytes] = None,
     ) -> None: ...
 
     @overload
@@ -779,7 +778,7 @@ class CameraDevice(Protocol):
         state_name: Literal["battery"],
         event_data: BatterySetEvent,
     ) -> None: ...
-    async def update_state(self, state_name: str, event_data: Any) -> None: ...
+    async def update_state(self, state_name: str, event_data: Any, frame: Optional[bytes] = None) -> None: ...
 
     @overload
     def on_state_change(
